==> webpdf-wsclient-2.0.2-sources.jar: net/webpdf/wsclient/schema/operation/BarcodeSelectionType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BarcodeSelectionType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BarcodeSelectionType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;all&gt;
 *         &lt;element name="scanArea" type="{http://schema.webpdf.de/1.0/operation}RectangleType"/&gt;
 *       &lt;/all&gt;
 *       &lt;attribute name="pages" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="resolution" default="200"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="1"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="pureBarcode" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="gs1" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="tryHarder" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *       &lt;attribute name="allowedLengths" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="barcode39CheckDigit" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="codabarStartEndDigits" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="upcEanExtensions" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="charset" type="{http://www.w3.org/2001/XMLSchema}string" default="utf-8" /&gt;
 *       &lt;attribute name="formats" use="required" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BarcodeSelectionType", propOrder = {

})
public class BarcodeSelectionType {

    @XmlElement(required = true)
    protected RectangleType scanArea;
    @XmlAttribute(name = "pages")
    protected String pages;
    @XmlAttribute(name = "resolution")
    protected Integer resolution;
    @XmlAttribute(name = "pureBarcode")
    protected Boolean pureBarcode;
    @XmlAttribute(name = "gs1")
    protected Boolean gs1;
    @XmlAttribute(name = "tryHarder")
    protected Boolean tryHarder;
    @XmlAttribute(name = "allowedLengths")
    protected String allowedLengths;
    @XmlAttribute(name = "barcode39CheckDigit")
    protected Boolean barcode39CheckDigit;
    @XmlAttribute(name = "codabarStartEndDigits")
    protected Boolean codabarStartEndDigits;
    @XmlAttribute(name = "upcEanExtensions")
    protected String upcEanExtensions;
    @XmlAttribute(name = "charset")
    protected String charset;
    @XmlAttribute(name = "formats", required = true)
    protected String formats;

    /**
     * Gets the value of the scanArea property.
     * 
     * @return
     *     possible object is
     *     {@link RectangleType }
     *     
     */
    public RectangleType getScanArea() {
        return scanArea;
    }

    /**
     * Sets the value of the scanArea property.
     * 
     * @param value
     *     allowed object is
     *     {@link RectangleType }
     *     
     */
    public void setScanArea(RectangleType value) {
        this.scanArea = value;
    }

    public boolean isSetScanArea() {
        return (this.scanArea!= null);
    }

    /**
     * Gets the value of the pages property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPages() {
        if (pages == null) {
            return "";
        } else {
            return pages;
        }
    }

    /**
     * Sets the value of the pages property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPages(String value) {
        this.pages = value;
    }

    public boolean isSetPages() {
        return (this.pages!= null);
    }

    /**
     * Gets the value of the resolution property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getResolution() {
        if (resolution == null) {
            return  200;
        } else {
            return resolution;
        }
    }

    /**
     * Sets the value of the resolution property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setResolution(int value) {
        this.resolution = value;
    }

    public boolean isSetResolution() {
        return (this.resolution!= null);
    }

    public void unsetResolution() {
        this.resolution = null;
    }

    /**
     * Gets the value of the pureBarcode property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isPureBarcode() {
        if (pureBarcode == null) {
            return false;
        } else {
            return pureBarcode;
        }
    }

    /**
     * Sets the value of the pureBarcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setPureBarcode(boolean value) {
        this.pureBarcode = value;
    }

    public boolean isSetPureBarcode() {
        return (this.pureBarcode!= null);
    }

    public void unsetPureBarcode() {
        this.pureBarcode = null;
    }

    /**
     * Gets the value of the gs1 property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isGs1() {
        if (gs1 == null) {
            return false;
        } else {
            return gs1;
        }
    }

    /**
     * Sets the value of the gs1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setGs1(boolean value) {
        this.gs1 = value;
    }

    public boolean isSetGs1() {
        return (this.gs1 != null);
    }

    public void unsetGs1() {
        this.gs1 = null;
    }

    /**
     * Gets the value of the tryHarder property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isTryHarder() {
        if (tryHarder == null) {
            return true;
        } else {
            return tryHarder;
        }
    }

    /**
     * Sets the value of the tryHarder property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setTryHarder(boolean value) {
        this.tryHarder = value;
    }

    public boolean isSetTryHarder() {
        return (this.tryHarder!= null);
    }

    public void unsetTryHarder() {
        this.tryHarder = null;
    }

    /**
     * Gets the value of the allowedLengths property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAllowedLengths() {
        if (allowedLengths == null) {
            return "";
        } else {
            return allowedLengths;
        }
    }

    /**
     * Sets the value of the allowedLengths property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAllowedLengths(String value) {
        this.allowedLengths = value;
    }

    public boolean isSetAllowedLengths() {
        return (this.allowedLengths!= null);
    }

    /**
     * Gets the value of the barcode39CheckDigit property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isBarcode39CheckDigit() {
        if (barcode39CheckDigit == null) {
            return false;
        } else {
            return barcode39CheckDigit;
        }
    }

    /**
     * Sets the value of the barcode39CheckDigit property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setBarcode39CheckDigit(boolean value) {
        this.barcode39CheckDigit = value;
    }

    public boolean isSetBarcode39CheckDigit() {
        return (this.barcode39CheckDigit!= null);
    }

    public void unsetBarcode39CheckDigit() {
        this.barcode39CheckDigit = null;
    }

    /**
     * Gets the value of the codabarStartEndDigits property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCodabarStartEndDigits() {
        if (codabarStartEndDigits == null) {
            return false;
        } else {
            return codabarStartEndDigits;
        }
    }

    /**
     * Sets the value of the codabarStartEndDigits property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCodabarStartEndDigits(boolean value) {
        this.codabarStartEndDigits = value;
    }

    public boolean isSetCodabarStartEndDigits() {
        return (this.codabarStartEndDigits!= null);
    }

    public void unsetCodabarStartEndDigits() {
        this.codabarStartEndDigits = null;
    }

    /**
     * Gets the value of the upcEanExtensions property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUpcEanExtensions() {
        if (upcEanExtensions == null) {
            return "";
        } else {
            return upcEanExtensions;
        }
    }

    /**
     * Sets the value of the upcEanExtensions property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUpcEanExtensions(String value) {
        this.upcEanExtensions = value;
    }

    public boolean isSetUpcEanExtensions() {
        return (this.upcEanExtensions!= null);
    }

    /**
     * Gets the value of the charset property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCharset() {
        if (charset == null) {
            return "utf-8";
        } else {
            return charset;
        }
    }

    /**
     * Sets the value of the charset property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCharset(String value) {
        this.charset = value;
    }

    public boolean isSetCharset() {
        return (this.charset!= null);
    }

    /**
     * Gets the value of the formats property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFormats() {
        return formats;
    }

    /**
     * Sets the value of the formats property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFormats(String value) {
        this.formats = value;
    }

    public boolean isSetFormats() {
        return (this.formats!= null);
    }

}

==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/BarcodeSelectionType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p523158_="https://jakarta.ee/xml/ns/jaxb" xmlns:p795835_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:p918168_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;This section is used to control the recognition process and configure settings that apply only to specific barcode types.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for BarcodeSelectionType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="BarcodeSelectionType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <all>
 *         <element name="scanArea" type="{http://schema.webpdf.de/1.0/operation}RectangleType"/>
 *       </all>
 *       <attribute name="pages" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *       <attribute name="resolution" default="200">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}int">
 *             <minInclusive value="1"/>
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="pureBarcode" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="gs1" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="tryHarder" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *       <attribute name="allowedLengths" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *       <attribute name="barcode39CheckDigit" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="codabarStartEndDigits" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="upcEanExtensions" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *       <attribute name="charset" type="{http://www.w3.org/2001/XMLSchema}string" default="utf-8" />
 *       <attribute name="formats" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BarcodeSelectionType", propOrder = {

})
public class BarcodeSelectionType {

    @XmlElement(required = true)
    protected RectangleType scanArea;
    @XmlAttribute(name = "pages")
    protected String pages;
    @XmlAttribute(name = "resolution")
    protected Integer resolution;
    @XmlAttribute(name = "pureBarcode")
    protected Boolean pureBarcode;
    @XmlAttribute(name = "gs1")
    protected Boolean gs1;
    @XmlAttribute(name = "tryHarder")
    protected Boolean tryHarder;
    @XmlAttribute(name = "allowedLengths")
    protected String allowedLengths;
    @XmlAttribute(name = "barcode39CheckDigit")
    protected Boolean barcode39CheckDigit;
    @XmlAttribute(name = "codabarStartEndDigits")
    protected Boolean codabarStartEndDigits;
    @XmlAttribute(name = "upcEanExtensions")
    protected String upcEanExtensions;
    @XmlAttribute(name = "charset")
    protected String charset;
    @XmlAttribute(name = "formats", required = true)
    protected String formats;

    /**
     * Gets the value of the scanArea property.
     * 
     * @return
     *     possible object is
     *     {@link RectangleType }
     *     
     */
    public RectangleType getScanArea() {
        return scanArea;
    }

    /**
     * Sets the value of the scanArea property.
     * 
     * @param value
     *     allowed object is
     *     {@link RectangleType }
     *     
     */
    public void setScanArea(RectangleType value) {
        this.scanArea = value;
    }

    public boolean isSetScanArea() {
        return (this.scanArea!= null);
    }

    /**
     * Gets the value of the pages property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPages() {
        if (pages == null) {
            return "";
        } else {
            return pages;
        }
    }

    /**
     * Sets the value of the pages property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPages(String value) {
        this.pages = value;
    }

    public boolean isSetPages() {
        return (this.pages!= null);
    }

    /**
     * Gets the value of the resolution property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getResolution() {
        if (resolution == null) {
            return  200;
        } else {
            return resolution;
        }
    }

    /**
     * Sets the value of the resolution property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setResolution(int value) {
        this.resolution = value;
    }

    public boolean isSetResolution() {
        return (this.resolution!= null);
    }

    public void unsetResolution() {
        this.resolution = null;
    }

    /**
     * Gets the value of the pureBarcode property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isPureBarcode() {
        if (pureBarcode == null) {
            return false;
        } else {
            return pureBarcode;
        }
    }

    /**
     * Sets the value of the pureBarcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setPureBarcode(boolean value) {
        this.pureBarcode = value;
    }

    public boolean isSetPureBarcode() {
        return (this.pureBarcode!= null);
    }

    public void unsetPureBarcode() {
        this.pureBarcode = null;
    }

    /**
     * Gets the value of the gs1 property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isGs1() {
        if (gs1 == null) {
            return false;
        } else {
            return gs1;
        }
    }

    /**
     * Sets the value of the gs1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setGs1(boolean value) {
        this.gs1 = value;
    }

    public boolean isSetGs1() {
        return (this.gs1 != null);
    }

    public void unsetGs1() {
        this.gs1 = null;
    }

    /**
     * Gets the value of the tryHarder property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isTryHarder() {
        if (tryHarder == null) {
            return true;
        } else {
            return tryHarder;
        }
    }

    /**
     * Sets the value of the tryHarder property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setTryHarder(boolean value) {
        this.tryHarder = value;
    }

    public boolean isSetTryHarder() {
        return (this.tryHarder!= null);
    }

    public void unsetTryHarder() {
        this.tryHarder = null;
    }

    /**
     * Gets the value of the allowedLengths property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAllowedLengths() {
        if (allowedLengths == null) {
            return "";
        } else {
            return allowedLengths;
        }
    }

    /**
     * Sets the value of the allowedLengths property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAllowedLengths(String value) {
        this.allowedLengths = value;
    }

    public boolean isSetAllowedLengths() {
        return (this.allowedLengths!= null);
    }

    /**
     * Gets the value of the barcode39CheckDigit property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isBarcode39CheckDigit() {
        if (barcode39CheckDigit == null) {
            return false;
        } else {
            return barcode39CheckDigit;
        }
    }

    /**
     * Sets the value of the barcode39CheckDigit property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setBarcode39CheckDigit(boolean value) {
        this.barcode39CheckDigit = value;
    }

    public boolean isSetBarcode39CheckDigit() {
        return (this.barcode39CheckDigit!= null);
    }

    public void unsetBarcode39CheckDigit() {
        this.barcode39CheckDigit = null;
    }

    /**
     * Gets the value of the codabarStartEndDigits property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCodabarStartEndDigits() {
        if (codabarStartEndDigits == null) {
            return false;
        } else {
            return codabarStartEndDigits;
        }
    }

    /**
     * Sets the value of the codabarStartEndDigits property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCodabarStartEndDigits(boolean value) {
        this.codabarStartEndDigits = value;
    }

    public boolean isSetCodabarStartEndDigits() {
        return (this.codabarStartEndDigits!= null);
    }

    public void unsetCodabarStartEndDigits() {
        this.codabarStartEndDigits = null;
    }

    /**
     * Gets the value of the upcEanExtensions property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUpcEanExtensions() {
        if (upcEanExtensions == null) {
            return "";
        } else {
            return upcEanExtensions;
        }
    }

    /**
     * Sets the value of the upcEanExtensions property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUpcEanExtensions(String value) {
        this.upcEanExtensions = value;
    }

    public boolean isSetUpcEanExtensions() {
        return (this.upcEanExtensions!= null);
    }

    /**
     * Gets the value of the charset property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCharset() {
        if (charset == null) {
            return "utf-8";
        } else {
            return charset;
        }
    }

    /**
     * Sets the value of the charset property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCharset(String value) {
        this.charset = value;
    }

    public boolean isSetCharset() {
        return (this.charset!= null);
    }

    /**
     * Gets the value of the formats property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFormats() {
        return formats;
    }

    /**
     * Sets the value of the formats property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFormats(String value) {
        this.formats = value;
    }

    public boolean isSetFormats() {
        return (this.formats!= null);
    }

}
